Skip to content
KitploitKITPLOIT
도구익스플로잇블로그
Log in
제출
도구익스플로잇블로그
제출

해킹, 침투 테스트 및 사이버 보안 도구를 당신의 보안 무기고에!

Kitploit은 해킹, 사이버 보안 및 침투 테스트 도구 디렉토리입니다. 최신 프로젝트 업데이트를 발견하여 취약점을 찾고, 시스템을 분석하고, 테스트를 자동화하고, 보안을 강화하세요.

피드문의개인정보© 2026 Kitploit

도구 디렉토리

카테고리

모든 카테고리 보기
Loading categories
ARTAXERXES — 고급 다중 기술 스트레스 테스트 프레임워크 고성능 네트워크 테스트를 위한 교육용 사이버보안 도구 | Kitploit
도구/GitLabGitLab/toxy4ny/artaxerxes
Network SecurityPenetration TestingLearning & EducationRed TeamingLabs & Practice
GitLabtoxy4ny/artaxerxes

ARTAXERXES

고급 다중 기술 스트레스 테스트 프레임워크 고성능 네트워크 테스트를 위한 교육용 사이버보안 도구

저장소 보기
932개월 전아직 검토되지 않음

인기

모두 보기 →

커뮤니티에서 가장 많이 사용되는 도구를 찾아보세요.

모든 도구 탐색

도구 컬렉션을 둘러보세요

모든 도구 보기 →
공유
웹사이트

ARTAXERXES 🚀

고급 멀티 테크놀로지 부하 테스트 프레임워크
고성능 네트워크 테스트를 위한 교육용 사이버보안 도구

License Platform CUDA Performance


📋 목차

  • 🎯 개요
  • ⚡ 성능 비교
  • 🛠️ 기술 스택
  • 📊 아키텍처
  • 🚀 빠른 시작
  • ⚙️ 설치
  • 💡 사용 예시
  • 🔧 고급 설정
  • 📈 벤치마크
  • 🧪 실험실 구성
  • 🎓 교육적 가치
  • ⚠️ 법적 고지

🎯 개요

Xerxes-Ultimate는 교육용 사이버보안 실험실을 위해 특별히 설계된 차세대 네트워크 부하 테스트 도구입니다. 원조 Xerxes DoS 도구의 기반 위에 구축된 이 구현은 최첨단 하드웨어 가속 기술을 활용하여 교육적 투명성을 유지하면서 전례 없는 성능 수준을 달성합니다.

주요 혁신

  • 🎮 멀티 GPU 가속: 페이로드 생성을 위해 최대 4x RTX 4070 Ti GPU 활용
  • ⚡ 제로 카피 I/O: io_uring 및 GPUDirect로 CPU 오버헤드 제거
  • 🌐 사용자 공간 네트워킹: DPDK로 커널 병목 현상 우회
  • 🔬 커널 수준 최적화: 궁극적인 성능을 위한 XDP/eBPF
  • 🧠 적응형 지능: 머신 러닝 기반 트래픽 패턴
  • 📊 실시간 분석: GPU 가속 통계 컴퓨팅

⚡ 성능 비교

원조 Xerxes vs Xerxes-Ultimate

지표원조 XerxesXerxes-Ultimate개선율
초당 패킷 수~50,000 PPS60,000,000+ PPS🚀 1,200배 빠름
대역폭~100 Mbps60+ Gbps🔥 600배 증가
동시 연결~1,0001,000,000+⚡ 1,000배 증가
CPU 효율성CPU 사용률 100%CPU 사용률 <30%💡 70% 절감
메모리 사용량높은 단편화최적화된 풀🎯 90% 효율적
지연 시간~1ms<100 나노초⚡ 10,000배 빠름

성능 등급```mermaid

graph LR A[Original Xerxes
50K PPS] --> B[BASIC Tier
100K PPS
2x improvement] B --> C[IO_URING Tier
1M PPS
20x improvement] C --> D[GPU Tier
10M PPS
200x improvement] D --> E[DPDK Tier
30M PPS
600x improvement] E --> F[ULTIMATE Tier
60M+ PPS
1,200x improvement]

---

## 🛠️ 기술 스택

### 핵심 기술

#### 🎮 **CUDA Multi-GPU Acceleration**```c
// Parallel payload generation across 4 GPUs
__global__ void generate_ultimate_payloads(char *payloads, int *sizes, 
                                          int payload_count, uint64_t seed) {
    int idx = blockIdx.x * blockDim.x + threadIdx.x;
    // 512 blocks × 1024 threads × 4 GPUs = 2,097,152 parallel generators
}

혜택:

  • 2,000,000+ 병렬 페이로드 생성기
  • 암호학적으로 강력한 무작위화
  • 패킷 생성 시 CPU 오버헤드 0
  • 버퍼링을 위한 총 16GB GPU 메모리

⚡ io_uring 제로카피 I/O```c

// Asynchronous submission queue struct io_uring ring; io_uring_queue_init(8192, &ring, IORING_SETUP_SQPOLL);

// Direct GPU->NIC transfer without CPU copies io_uring_prep_send_zc(sqe, socket_fd, gpu_buffer, size, 0);

**이점:**
- **400% I/O 성능 향상**
- **제로카피 GPU-to-NIC 전송**
- **컨텍스트 스위칭 오버헤드 제거**
- **100,000개 이상의 동시 작업으로 확장**

#### 🌐 **DPDK 사용자 공간 네트워킹**```c
// Bypass kernel network stack entirely
struct rte_mbuf *pkts[BURST_SIZE];
uint16_t nb_tx = rte_eth_tx_burst(port_id, queue_id, pkts, nb_pkts);

장점:

  • 500% 패킷 처리 성능 향상
  • 직접 하드웨어 액세스
  • 예측 가능한 지연 시간 (<100ns)
  • 라인레이트 100GbE 성능

🔬 XDP/eBPF 커널 프로그래밍```c

SEC("xdp_ultimate") int xdp_stress_program(struct xdp_md *ctx) { // Kernel-level packet manipulation return XDP_TX; // Retransmit at wire speed }

**이점:**
- **사용자 공간 대비 200% 효율 향상**
- **커널 수준 패킷 생성**
- **프로그래밍 가능한 패킷 처리**
- **하드웨어 오프로드 통합**

---

## 📊 아키텍처

### 시스템 아키텍처 개요```mermaid
graph TB
    subgraph "User Space"
        A[Control Thread] --> B[Thread Pool Manager]
        B --> C[GPU Generator Threads]
        B --> D[Network Transmit Threads]
        B --> E[Statistics Monitor]
    end
    
    subgraph "GPU Cluster"
        F[RTX 4070 Ti #1<br/>2,560 cores]
        G[RTX 4070 Ti #2<br/>2,560 cores]
        H[RTX 4070 Ti #3<br/>2,560 cores]
        I[RTX 4070 Ti #4<br/>2,560 cores]
        
        F --> J[GPU Memory Pool<br/>48GB Total]
        G --> J
        H --> J
        I --> J
    end
    
    subgraph "I/O Subsystem"
        K[io_uring Ring<br/>8192 entries]
        L[DPDK PMD Drivers]
        M[Zero-Copy Buffers]
    end
    
    subgraph "Kernel Space"
        N[XDP Hook]
        O[eBPF Programs]
        P[Network Interface]
    end
    
    C --> F
    C --> G
    C --> H 
    C --> I
    
    D --> K
    D --> L
    K --> M
    L --> M
    
    M --> N
    N --> O
    O --> P
    
    P --> Q[Target Network<br/>60+ Gbps]

메모리 아키텍처```mermaid

graph LR subgraph "GPU Memory (16GB)" A[Payload Buffers
8GB] B[Size Arrays
2GB] C[Random States
4GB] D[Working Space
2GB] end

subgraph "Host Memory (32GB)"
    E[Pinned Buffers<br/>16GB]
    F[Ring Buffers<br/>8GB]
    G[Connection Pool<br/>4GB]
    H[Statistics<br/>4GB]
end

subgraph "NIC Memory (1GB)"
    I[DMA Buffers<br/>512MB]
    J[Descriptor Rings<br/>256MB]
    K[Hardware Queues<br/>256MB]
end

A -.->|PCIe 4.0<br/>64 GB/s| E
E -.->|Zero-Copy| F
F -.->|DMA| I
---

## 🚀 빠른 시작

### 사전 요구 사항 확인```bash
# Run the capability detector
./scripts/check-capabilities.sh

예상 출력:``` 🔍 Xerxes-Ultimate Capability Check

[✓] CUDA: 4 GPUs detected [✓] DPDK: Compatible NIC detected
[✓] io_uring: Kernel support available [✓] XDP/eBPF: Root privileges available

### 기본 실행```bash
# Simple unlimited attack
./artaxerxes-ultimate 192.168.1.100 80

# Controlled burst testing
./artaxerxes-ultimate 192.168.1.100 80 10M_pps

# Bandwidth-limited testing  
./artaxerxes-ultimate 192.168.1.100 80 5Gbps

# Time-limited demonstration
./artaxerxes-ultimate 192.168.1.100 80 300s

⚙️ 설치

자동 설치```bash

Clone repository

git clone https://gitlab.com/toxy4ny/ARTAXERXES.git cd ARTAXERXES

Run quick deployment script

sudo quick-deploy.sh

### 수동 설치

#### 1. 의존성 설치

**Ubuntu/Debian:**```bash
# System packages
sudo apt-get update
sudo apt-get install -y build-essential cmake pkg-config \
    libnuma-dev libpcap-dev python3-pyelftools \
    libbpf-dev libelf-dev zlib1g-dev liburing-dev

# CUDA Toolkit (if not installed)
wget https://developer.download.nvidia.com/compute/cuda/12.3.0/local_installers/cuda_12.3.0_545.23.06_linux.run
sudo sh cuda_12.3.0_545.23.06_linux.run

# DPDK
wget http://fast.dpdk.org/rel/dpdk-22.11.1.tar.xz
tar xf dpdk-22.11.1.tar.xz
cd dpdk-22.11.1
meson setup build
cd build && ninja && sudo ninja install

CentOS/RHEL:```bash

Enable EPEL and PowerTools

sudo dnf install epel-release sudo dnf config-manager --set-enabled powertools

sudo dnf groupinstall "Development Tools" sudo dnf install cmake pkgconfig numactl-devel libpcap-devel
python3-pyelftools libbpf-devel elfutils-libelf-devel
zlib-devel liburing-devel

#### 2. 기능 감지로 빌드```bash
# Build with all available features
make

# Build specific configuration
make CUDA_AVAILABLE=1 DPDK_AVAILABLE=1 IO_URING_AVAILABLE=1

3. 시스템 전체에 설치```bash

sudo make install

### Docker 설치```bash
# Build container with all dependencies
docker build -t xerxes-ultimate .

# Run with GPU support
docker run --gpus all --privileged --net=host \
    xerxes-ultimate 192.168.1.100 80 1Gbps

💡 사용 예시

교육용 랩 시나리오

시나리오 1: 기본 성능 데모```bash

Start with minimal load to show baseline

./artaxerxes 192.168.1.100 80 100K_pps

Gradually increase to show scaling

./artaxerxes 192.168.1.100 80 1M_pps ./artaxerxes 192.168.1.100 80 10M_pps ./artaxerxes 192.168.1.100 80 50M_pps

**예상 학습 성과:**
- 초당 패킷 처리량 확장 이해
- 하드웨어 가속의 영향
- 네트워크 병목 현상 식별
도구 다운로드